Introduction
============

The ``debops.nfs`` Ansible role can be used to configure NFS shares on
Debian/Ubuntu hosts.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.2.0``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops.nfs

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
